@@ -44,6 +44,7 @@
 
 #include <QCursor>
 #include <QDir>
+#include <QDirIterator>
 #include <QToolTip>
 #include <QFile>
 #include <QResizeEvent>
@@ -61,7 +62,6 @@
 
 #include <time.h>
 #include <cmath>
-#include <dirent.h>
 
 #include "playlistitem.h"
 #include "playlistcollection.h"
@@ -596,7 +596,7 @@ void Playlist::updateDeletedItem(PlaylistItem *item)
     m_subtractTime.removeAll(item);
 }
 
-void Playlist::clearItem(PlaylistItem *item, bool emitChanged)
+void Playlist::clearItem(PlaylistItem *item)
 {
     // Automatically updates internal structs via updateDeletedItem
     delete item;
@@ -1875,54 +1875,43 @@ void Playlist::addFile(const QString &file, FileHandleList &files, bool importPl
         return;
     }
 
-
-    const QFileInfo fileInfo = QDir::cleanPath(file);
+    const QFileInfo fileInfo(QDir::cleanPath(file));
     if(!fileInfo.exists())
         return;
 
+    const QString canonicalPath = fileInfo.canonicalFilePath();
+
     if(fileInfo.isFile() && fileInfo.isReadable()) {
         if(MediaFiles::isMediaFile(file)) {
-            FileHandle f(fileInfo, fileInfo.absoluteFilePath());
+            FileHandle f(fileInfo, canonicalPath);
             f.tag();
             files.append(f);
         }
     }
 
     if(importPlaylists && MediaFiles::isPlaylistFile(file) &&
-       !m_collection->containsPlaylistFile(fileInfo.canonicalFilePath()))
+       !m_collection->containsPlaylistFile(canonicalPath))
     {
         new Playlist(m_collection, fileInfo);
         return;
     }
 
     if(fileInfo.isDir()) {
-
-        // Resorting to the POSIX API because QDir::listEntries() stats every
-        // file and blocks while it's doing so.
-
-        DIR *dir = ::opendir(QFile::encodeName(fileInfo.filePath()));
-
-        if(dir) {
-            struct dirent *dirEntry;
-
-            for(dirEntry = ::readdir(dir); dirEntry; dirEntry = ::readdir(dir)) {
-                if(strcmp(dirEntry->d_name, ".") != 0 && strcmp(dirEntry->d_name, "..") != 0) {
-
-                    // We set importPlaylists to the value from the add directories
-                    // dialog as we want to load all of the ones that the user has
-                    // explicitly asked for, but not those that we find in toLower
-                    // directories.
-
-                    addFile(fileInfo.filePath() + QDir::separator() + QFile::decodeName(dirEntry->d_name),
-                            files, m_collection->importPlaylists(), after);
-                }
-            }
-            ::closedir(dir);
+        foreach(const QString &directory, m_collection->excludedFolders()) {
+            if(canonicalPath.startsWith(directory))
+                return; // Exclude it
         }
-        else {
-            kWarning() << "Unable to open directory "
-                            << fileInfo.filePath()
-                            << ", make sure it is readable.\n";
+
+        QDirIterator dirIterator(canonicalPath, QDir::AllEntries | QDir::NoDotAndDotDot);
+
+        while(dirIterator.hasNext()) {
+            // We set importPlaylists to the value from the add directories
+            // dialog as we want to load all of the ones that the user has
+            // explicitly asked for, but not those that we find in toLower
+            // directories.
+
+            addFile(dirIterator.next(), files,
+                    m_collection->importPlaylists(), after);
         }
     }
 }
